==> kmysqladmin-0.4.1.tar.gz: kmysqladmin-0.4.1/kmysqladmin/stringres.cpp <==
#include <kapp.h>
#include "stringres.h"

#ifdef i18n
#undef i18n
#endif

#define i18n(X) std::string(X)

const string_res CStringRes::res_array[]=
{
    string_res(  0,i18n("The key")),
    string_res(  1,i18n("is already in the keylist")),
    string_res(  2,i18n("Adding key")),
    string_res(  3,i18n("Create Table")),
    string_res(  4,i18n("No DBs found")),
    string_res(  5,i18n("Not connected")),
    string_res(  6,i18n("Error inserting column")),
    string_res(  7,i18n("Enter another name for column")),
    string_res(  8,i18n("There is already a primary key")),
    string_res(  9,i18n("Error modify column")),
    string_res( 10,i18n("Please look into the logwindow, what going wrong")),
    string_res( 11,i18n("Error deleting table")),
    string_res( 12,i18n("With this software you can not delete a table of the systemdatabase")),
    string_res( 13,i18n("Do you realy want to delete the table")),
    string_res( 14,i18n("Realy all data will be lost!")),
    string_res( 15,i18n("Deleting table")),
    string_res( 16,i18n("Of course")),
    string_res( 17,i18n("Never!")),
    string_res( 18,i18n("Reset")),
    string_res( 19,i18n("Select")),
    string_res( 20,i18n("Update")),
    string_res( 21,i18n("Create")),
    string_res( 22,i18n("Drop")),
    string_res( 23,i18n("ShutDown")),
    string_res( 24,i18n("Process")),
    string_res( 25,i18n("User:")),
    string_res( 26,i18n("Database:")),
    string_res( 27,i18n("Password:")),
    string_res( 28,i18n("Retype Pass:")),
    string_res( 29,i18n(" - Edit grants")),
    string_res( 30,i18n("Edit User-Rights")),
    string_res( 31,i18n("Edit DB-Rights")),
    string_res( 32,i18n("Add Host")),
    string_res( 33,i18n("Add User")),
    string_res( 34,i18n("Add Db to user")),
    string_res( 35,i18n("You had typed in different passwords")),
    string_res( 36,i18n("please try again")),
    string_res( 37,i18n("Error with password")),
    string_res( 38,i18n("Error with username")),
    string_res( 39,i18n("You had not typed in a username")),
    string_res( 40,i18n("Modify")),
    string_res( 41,i18n("Hosts:")),
    string_res( 42,i18n("Users from selected host:")),
    string_res( 43,i18n("DB access for selected user:")),
    string_res( 44,i18n("&Refresh")),
    string_res( 45,i18n("KMySQL - Connect")),
    string_res( 46,i18n("Insert information")),
    string_res( 47,i18n("&Disconnect")),
    string_res( 48,i18n("&Clear output")),
    string_res( 49,i18n("&Log output to file")),
    string_res( 50,i18n("Drop &database...")),
    string_res( 51,i18n("Drop &table...")),
    string_res( 52,i18n("&Flush host cache")),
    string_res( 53,i18n("&Close open tables")),
    string_res( 54,i18n("&Begin new server log")),
    string_res( 55,i18n("&Reload permissions")),
    string_res( 56,i18n("Shutdown server")),
    string_res( 57,i18n("&Database")),
    string_res( 58,i18n("MySQL Administrationtool")),
    string_res( 59,i18n("written by Rajko Albrecht")),
    string_res( 60,i18n("Aachen (FRG)")),
    string_res( 61,i18n("Could not connect to SQL-Server!")),
    string_res( 62,i18n("Please check username and password")),
    string_res( 63,i18n("Error connect")),
    string_res( 64,i18n("&Connect")),
    string_res( 65,i18n("&Grants")),
    string_res( 66,i18n("&Thread")),
    string_res( 67,i18n("Create &DB")),
    string_res( 68,i18n("Cr&eate table")),
    string_res( 69,i18n("&Alter table")),
    string_res( 70,i18n("&Status")),
    string_res( 71,i18n("&Browse tables")),
    string_res( 72,i18n("Select file to save")),
    string_res( 73,i18n("Save as")),
    string_res( 74,i18n("Insert filename:")),
    string_res( 75,i18n("Plain ascii")),
    string_res( 76,i18n("KMySQL - TableView")),
    string_res( 77,i18n("Insert data")),
    string_res( 78,i18n("Search (use % as wildcard!)")),
    string_res( 79,i18n("Deleting row")),
    string_res( 80,i18n("Do you realy want to delete this row?")),
    string_res( 81,i18n("Do you realy want to empty the complete table?")),
    string_res( 82,i18n("Empty table")),
    string_res( 83,i18n("Error open file")),
    string_res( 84,i18n("This is a directory, not a file!!!")),
    string_res( 85,i18n("The file")),
    string_res( 86,i18n("does exists. Overwrite?")),
    string_res( 87,i18n("Overwriting file")),
    string_res( 88,i18n("You have no write permission!")),
    string_res( 89,i18n("Select Data")),
    string_res( 90,i18n("Database")),
    string_res( 91,i18n("Table")),
    string_res( 92,i18n("Sort by")),
    string_res( 93,i18n("Limit Offset")),
    string_res( 94,i18n("Limit Count")),
    string_res( 95,i18n("&Add Row")),
    string_res( 96,i18n("&Modify Row")),
    string_res( 97,i18n("Delete selected")),
    string_res( 98,i18n("&Search")),
    string_res( 99,i18n("Sa&ve")),
    string_res(100,i18n("Delete All")),
    string_res(101,i18n("&Go!")),
    string_res(102,i18n("&Refresh DB-List")),
    string_res(103,i18n("Insert new Database Name")),
    string_res(104,i18n("Clear Output")),
    string_res(105,i18n("Refresh")),
    string_res(106,i18n("Table View")),
    string_res(107,i18n("Kill selected")),
    string_res(108,i18n("Cancel")),
    string_res(109,i18n("&File")),
    string_res(110,i18n("Rename table...")),
    string_res(111,i18n("&Help")),
    string_res(112,i18n("Error")),
    string_res(113,i18n("&Close")),
    string_res(114,i18n("Alter table")),
    string_res(115,i18n("Save")),
    string_res(116,i18n("Insert")),
    string_res(117,i18n("Delete")),
    string_res(118,i18n("Reload")),
    string_res(119,i18n("Add")),
    string_res(120,i18n("Error altering table")),
    string_res(121,i18n("Error creating table")),
    string_res(122,i18n("&New window")),
    string_res(123,i18n("&Close window")),
    string_res(124,i18n("not connected")),
    string_res(125,i18n("KMySQLAdmin")),
    string_res(126,i18n("Create table")),
    string_res(127,i18n("Thread view")),
    string_res(128,i18n("Change table name")),
    string_res(129,i18n("Status view")),
    string_res(130,i18n("Are you sure to shutdown the server?")),
    string_res(131,i18n("Failure while doing the statement")),
    string_res(132,i18n("Execute")),
    string_res(133,i18n("&Save script")),
    string_res(134,i18n("&Load script")),
    string_res(135,i18n("&New script")),
    string_res(136,i18n("Ready")),
    string_res(137,i18n("You had errors while running the script")),
    string_res(138,i18n("Finished the script")),
    string_res(139,i18n("Running the script")),
    string_res(140,i18n("Save &results")),
    string_res(141,i18n("Search again")),
    string_res(142,i18n("Edit")),
    string_res(143,i18n(" - enter text")),
    string_res(144,i18n("Enter search string")),
};

#undef i18n
#define translate(X) KApplication::getKApplication()->getLocale()->translate(X)

const char* CStringRes::get_string(unsigned int id)
{
    unsigned int size = sizeof(res_array)/sizeof(string_res);
    for (unsigned int count = 0;count < size;++count) {
	if(res_array[count].first == id)
	    return translate(res_array[count].second.c_str());
    }
    return "";
}

==> kmysqladmin-0.5.1.tar.gz: kmysqladmin-0.5.1/kmysqladmin/stringres.cpp <==
#include "stringres.h"
#include "stdio.h"

#ifdef i18n
#undef i18n
#endif

#define i18n(X) std::string(X)

const string_res CStringRes::res_array[]=
{
    string_res(  0,i18n("The key")),
    string_res(  1,i18n("is already in the keylist")),
    string_res(  2,i18n("Adding key")),
    string_res(  3,i18n("Create Table")),
    string_res(  4,i18n("No DBs found")),
    string_res(  5,i18n("Not connected")),
    string_res(  6,i18n("Error inserting column")),
    string_res(  7,i18n("Enter another name for column")),
    string_res(  8,i18n("There is already a primary key")),
    string_res(  9,i18n("Error modify column")),
    string_res( 10,i18n("Please look into the logwindow, what going wrong")),
    string_res( 11,i18n("Error deleting table")),
    string_res( 12,i18n("With this software you can not delete a table of the systemdatabase")),
    string_res( 13,i18n("Do you realy want to delete the table")),
    string_res( 14,i18n("Realy all data will be lost!")),
    string_res( 15,i18n("Deleting table")),
    string_res( 16,i18n("Of course")),
    string_res( 17,i18n("Never!")),
    string_res( 18,i18n("Reset")),
    string_res( 19,i18n("Select")),
    string_res( 20,i18n("Update")),
    string_res( 21,i18n("Create")),
    string_res( 22,i18n("Drop")),
    string_res( 23,i18n("ShutDown")),
    string_res( 24,i18n("Process")),
    string_res( 25,i18n("User:")),
    string_res( 26,i18n("Database:")),
    string_res( 27,i18n("Password:")),
    string_res( 28,i18n("Retype Pass:")),
    string_res( 29,i18n(" - Edit grants")),
    string_res( 30,i18n("Edit User-Rights")),
    string_res( 31,i18n("Edit DB-Rights")),
    string_res( 32,i18n("Add Host")),
    string_res( 33,i18n("Add User")),
    string_res( 34,i18n("Add Db to user")),
    string_res( 35,i18n("You had typed in different passwords")),
    string_res( 36,i18n("please try again")),
    string_res( 37,i18n("Error with password")),
    string_res( 38,i18n("Error with username")),
    string_res( 39,i18n("You had not typed in a username")),
    string_res( 40,i18n("Modify")),
    string_res( 41,i18n("Hosts:")),
    string_res( 42,i18n("Users from selected host:")),
    string_res( 43,i18n("DB access for selected user:")),
    string_res( 44,i18n("&Refresh")),
    string_res( 45,i18n("KMySQL - Connect")),
    string_res( 46,i18n("Insert information")),
    string_res( 47,i18n("&Disconnect")),
    string_res( 48,i18n("&Clear output")),
    string_res( 49,i18n("&Log output to file")),
    string_res( 50,i18n("Drop &database...")),
    string_res( 51,i18n("Drop &table...")),
    string_res( 52,i18n("&Flush host cache")),
    string_res( 53,i18n("&Close open tables")),
    string_res( 54,i18n("&Begin new server log")),
    string_res( 55,i18n("&Reload permissions")),
    string_res( 56,i18n("Shutdown server")),
    string_res( 57,i18n("&Database")),
    string_res( 58,i18n("MySQL Administrationtool")),
    string_res( 59,i18n("written by Rajko Albrecht")),
    string_res( 60,i18n("Aachen (FRG)")),
    string_res( 61,i18n("Could not connect to SQL-Server!")),
    string_res( 62,i18n("Please check username and password")),
    string_res( 63,i18n("Error connect")),
    string_res( 64,i18n("&Connect")),
    string_res( 65,i18n("&Grants")),
    string_res( 66,i18n("&Thread")),
    string_res( 67,i18n("Create &DB")),
    string_res( 68,i18n("Cr&eate table")),
    string_res( 69,i18n("&Alter table")),
    string_res( 70,i18n("&Status")),
    string_res( 71,i18n("&Browse tables")),
    string_res( 72,i18n("Select file to save")),
    string_res( 73,i18n("Save as")),
    string_res( 74,i18n("Insert filename:")),
    string_res( 75,i18n("Plain ascii")),
    string_res( 76,i18n("KMySQL - TableView")),
    string_res( 77,i18n("Insert data")),
    string_res( 78,i18n("Search (use % as wildcard!)")),
    string_res( 79,i18n("Deleting row")),
    string_res( 80,i18n("Do you realy want to delete this row?")),
    string_res( 81,i18n("Do you realy want to empty the complete table?")),
    string_res( 82,i18n("Empty table")),
    string_res( 83,i18n("Error open file")),
    string_res( 84,i18n("This is a directory, not a file!!!")),
    string_res( 85,i18n("The file")),
    string_res( 86,i18n("does exists. Overwrite?")),
    string_res( 87,i18n("Overwriting file")),
    string_res( 88,i18n("You have no write permission!")),
    string_res( 89,i18n("Select Data")),
    string_res( 90,i18n("Database")),
    string_res( 91,i18n("Table")),
    string_res( 92,i18n("Sort by")),
    string_res( 93,i18n("Limit Offset")),
    string_res( 94,i18n("Limit Count")),
    string_res( 95,i18n("&Add Row")),
    string_res( 96,i18n("&Modify Row")),
    string_res( 97,i18n("Delete selected")),
    string_res( 98,i18n("&Search")),
    string_res( 99,i18n("Sa&ve")),
    string_res(100,i18n("Delete All")),
    string_res(101,i18n("&Go!")),
    string_res(102,i18n("&Refresh DB-List")),
    string_res(103,i18n("Insert new Database Name")),
    string_res(104,i18n("Clear Output")),
    string_res(105,i18n("Refresh")),
    string_res(106,i18n("Table View")),
    string_res(107,i18n("Kill selected")),
    string_res(108,i18n("Cancel")),
    string_res(109,i18n("&File")),
    string_res(110,i18n("Rename table...")),
    string_res(111,i18n("&Help")),
    string_res(112,i18n("Error")),
    string_res(113,i18n("&Close")),
    string_res(114,i18n("Alter table")),
    string_res(115,i18n("Save")),
    string_res(116,i18n("Insert")),
    string_res(117,i18n("Delete")),
    string_res(118,i18n("Reload")),
    string_res(119,i18n("Add")),
    string_res(120,i18n("Error altering table")),
    string_res(121,i18n("Error creating table")),
    string_res(122,i18n("&New window")),
    string_res(123,i18n("&Close window")),
    string_res(124,i18n("not connected")),
    string_res(125,i18n("KMySQLAdmin")),
    string_res(126,i18n("Create table")),
    string_res(127,i18n("Thread view")),
    string_res(128,i18n("Change table name")),
    string_res(129,i18n("Status view")),
    string_res(130,i18n("Are you sure to shutdown the server?")),
    string_res(131,i18n("Failure while doing the statement")),
    string_res(132,i18n("Execute")),
    string_res(133,i18n("&Save script")),
    string_res(134,i18n("&Load script")),
    string_res(135,i18n("&New script")),
    string_res(136,i18n("Ready")),
    string_res(137,i18n("You had errors while running the script")),
    string_res(138,i18n("Finished the script")),
    string_res(139,i18n("Running the script")),
    string_res(140,i18n("Save &results")),
    string_res(141,i18n("Search again")),
    string_res(142,i18n("Edit")),
    string_res(143,i18n(" - enter text")),
    string_res(144,i18n("Enter search string")),
    string_res(145,i18n("&Restore last login")),
    string_res(146,i18n("&Setup")),
    string_res(147,i18n("Ok")),
    string_res(148,i18n("Host")),
    string_res(149,i18n("&Quit")),
    string_res(150,i18n("SQL Editor")),
    string_res(151,i18n("&General setup"))
};

#undef i18n

#ifndef _WIN32
//#define translate(X) KApplication::getKApplication()->getLocale()->translate(X)
#endif

const char* CStringRes::get_string(unsigned int id)
{
    unsigned int size = sizeof(res_array)/sizeof(string_res);
    for (unsigned int count = 0;count < size;++count) {
	if(res_array[count].first == id) {
#ifndef _WIN32
            return res_array[count].second.c_str();
#else
            return res_array[count].second.c_str();
#endif
        }
    }
    return "";
}
